@@ -8,6 +8,5 @@ Yproduct <- function(S, M){
   for (i in 1:ncol(S)) {
     product[,(1 + ncol(M)*(i-1)):(ncol(M)*i)] <- S[,i]*M
   }
-  return
-  product
+  return(product)
 }
